@@ -17,6 +17,7 @@
 
 #include <QDebug>
 #include <QSharedPointer>
+#include <QVariant>
 
 #include <memory>
 
@@ -71,8 +72,11 @@ private:
 inline CDebug&
 operator<<( CDebug&& s, const FuncSuppressor& f )
 {
-    s.m_funcinfo = nullptr;
-    s << f.m_s;
+    if ( s.m_funcinfo )
+    {
+        s.m_funcinfo = nullptr;
+        s.m_msg = QString( f.m_s );
+    }
     return s;
 }
 
@@ -145,8 +149,8 @@ public:
     {
     }
 
-    const T& first;
-    const U& second;
+    const T first;
+    const U second;
 };
 
 /**
@@ -207,6 +211,49 @@ public:
     const QVariantMap& map;
 };
 
+/** @brief When logging commands, don't log everything.
+ *
+ * The command-line arguments to some commands may contain the
+ * encrypted password set by the user. Don't log that password,
+ * since the log may get posted to bug reports, or stored in
+ * the target system.
+ */
+struct RedactedCommand
+{
+    RedactedCommand( const QStringList& l )
+        : list( l )
+    {
+    }
+
+    const QStringList& list;
+};
+
+DLLEXPORT QDebug& operator<<( QDebug& s, const RedactedCommand& l );
+
+/** @brief When logging "private" identifiers, keep them consistent but private
+ *
+ * Send a string to a logger in such a way that each time it is logged,
+ * it logs the same way, but without revealing the actual contents.
+ * This can be applied to user names, UUIDs, etc.
+ */
+struct DLLEXPORT RedactedName
+{
+    RedactedName( const char* context, const QString& s );
+    RedactedName( const QString& context, const QString& s );
+
+    operator QString() const;
+
+private:
+    const uint m_id;
+    const QString m_context;
+};
+
+inline QDebug&
+operator<<( QDebug& s, const RedactedName& n )
+{
+    return s << NoQuote << QString( n ) << Quote;
+}
+
 /**
  * @brief Formatted logging of a pointer
  *
@@ -265,7 +312,7 @@ operator<<( QDebug& s, const DebugListT< T >& c )
 }
 
 /** @brief supporting method for outputting a DebugMap */
-QString toString( const QVariant& v );
+DLLEXPORT QString toString( const QVariant& v );
 
 /** @brief output operator for DebugMap */
 inline QDebug&
@@ -310,6 +357,20 @@ public:
     }
     friend CDebug& operator<<( CDebug&&, const Once& );
 
+    /** @brief Restore the object to "fresh" state
+     *
+     * It may be necessary to allow the Once object to stream the
+     * function header again -- for instance, after logging an error,
+     * any following debug log might want to re-introduce the header.
+     */
+    void refresh() { m = true; }
+
+    /** @brief Is this object "fresh"?
+     *
+     * Once a Once-object has printed (once) it is no longer fresh.
+     */
+    operator bool() const { return m; }
+
 private:
     mutable bool m = false;
 };
