@@ -48,7 +48,7 @@ class UnpackEntry:
     :param destination:
     """
     __slots__ = ('source', 'sourcefs', 'destination', 'copied', 'total', 'exclude', 'excludeFile',
-                 'mountPoint', 'weight')
+                 'mountPoint', 'weight', 'condition')
 
     def __init__(self, source, sourcefs, destination):
         """
@@ -71,6 +71,7 @@ class UnpackEntry:
         self.total = 0
         self.mountPoint = None
         self.weight = 1
+        self.condition = True
 
     def is_file(self):
         return self.sourcefs == "file"
@@ -419,6 +420,18 @@ def extract_weight(entry):
     return 1
 
 
+def fetch_from_globalstorage(keys_list):
+    value = libcalamares.globalstorage.value(keys_list[0])
+    if value is None:
+        return None
+    for key in keys_list[1:]:
+        if isinstance(value, dict) and key in value:
+            value = value[key]
+        else:
+            return None
+    return value
+
+
 def run():
     """
     Unsquash filesystem.
@@ -474,6 +487,28 @@ def run():
         sourcefs = entry["sourcefs"]
         destination = os.path.abspath(root_mount_point + entry["destination"])
 
+        condition = entry.get("condition", True)
+        if isinstance(condition, bool):
+            pass  # 'condition' is already True or False
+        elif isinstance(condition, str):
+            keys = condition.split(".")
+            gs_value = fetch_from_globalstorage(keys)
+            if gs_value is None:
+                libcalamares.utils.warning("Condition key '{}' not found in global storage, assuming False".format(condition))
+                condition = False
+            elif isinstance(gs_value, bool):
+                condition = gs_value
+            else:
+                libcalamares.utils.warning("Condition key '{}' is not a boolean, assuming True".format(condition))
+                condition = True
+        else:
+            libcalamares.utils.warning("Invalid 'condition' value '{}', assuming True".format(condition))
+            condition = True
+
+        if not condition:
+            libcalamares.utils.debug("Skipping unpack of {} due to 'condition' being False".format(source))
+            continue
+
         if not os.path.isdir(destination) and sourcefs != "file":
             libcalamares.utils.warning(("The destination \"{}\" in the target system is not a directory").format(destination))
             if is_first:
